@@ -110,6 +110,98 @@ define(function(require) {
     });
     $("#q-toggle").click(qf.toggle.bind(qf));
 
+
+    // connect drag and drop from cstatsview to query form
+    (function() {
+      function checkHit(activeEl, targetId, ev) {
+        // check if overlaps with qf elements
+        var xel = $(targetId);
+        var parPos = xel.offsetParent().position();
+        var xPos = xel.position();
+        xPos.left += parPos.left;
+        xPos.top += parPos.top;
+        var xDim = xel.get()[0].getBBox();
+        var pad = 3;
+        var cstatOff = {
+          left: initOffset.left + ev.pageX - initMouse.left,
+          top: initOffset.top + ev.pageY - initMouse.top
+        };
+
+        return !(
+          xPos.left+xDim.width < cstatOff.left-pad ||
+          cstatOff.left+activeEl.width()+pad+pad < xPos.left ||
+          xPos.top+xDim.height < cstatOff.top-pad ||
+          cstatOff.top+activeEl.height()+pad+pad < xPos.top
+        ) 
+      }
+
+
+      var activeCStat = null;
+      var activeEl = null;
+      var initOffset = null;
+      var initMouse = null;
+      var parent = null;
+      csv.on("dragStart", function(cstatview, ev) {
+        activeCStat = cstatview.model;
+        activeEl = cstatview.$el.find(".col-name");
+        parent = activeEl.parent();
+        initOffset = activeEl.offset();
+        initMouse = {left: ev.pageX, top: ev.pageY}
+        activeEl = activeEl.clone();
+        activeEl.remove().appendTo($("body"));
+      });
+      csv.on("drag", function(cstatview, ev) {
+        if (activeEl) {
+          activeEl.css({
+            position: "absolute",
+            left: initOffset.left + ev.pageX - initMouse.left,
+            top: initOffset.top + ev.pageY - initMouse.top
+          });
+          if (checkHit(activeEl, "#viz .xaxis", ev)) {
+            $("#viz .xaxis rect").attr("fill", "steelblue");
+            activeEl.addClass("active");
+          } else {
+            $("#viz .xaxis rect").attr("fill", "none");
+            activeEl.removeClass("active");
+
+            if (util.isNum(cstatview.model.get("type"))) {
+              if (checkHit(activeEl, "#viz .yaxis", ev)) {
+                $("#viz .yaxis rect").attr("fill", "steelblue");
+                activeEl.addClass("active");
+              } else {
+                $("#viz .yaxis rect").attr("fill", "none");
+                activeEl.removeClass("active");
+              }
+            }
+          }
+
+        }
+      });
+      csv.on("dragEnd", function(cstatview, ev) {
+        if (activeEl) {
+          if (checkHit(activeEl, "#viz .xaxis", ev)) {
+            qf.$("input[name=q-x-expr]").val(cstatview.model.get("col"));
+            qf.$("input[name=q-x-col]").val(cstatview.model.get("col"));
+            qf.onSubmit();
+          } else if (checkHit(activeEl, "#viz .yaxis", ev)) {
+            qf.$("input[name=q-y-expr]").remove();
+            qf.$("input[name=q-y-col]").remove();
+            qf.onAggAdd.call(qf);
+            if (util.isNum(cstatview.model.get("type"))) {
+              qf.$("input[name=q-y-expr]").val("avg("+cstatview.model.get("col")+")");
+              qf.$("input[name=q-y-col]").val(cstatview.model.get("col"));
+              qf.onSubmit();
+            }
+          } 
+          $("#viz .xaxis rect").attr("fill", "none");
+          $("#viz .yaxis rect").attr("fill", "none");
+          activeEl.remove();
+          activeCStat = activeEl = null;
+        }
+      });
+    })();
+
+
     where.on('change:selection', function() {
       var defaultOpts = {silent: false, clear: true};
       var opts = null;
